@@ -1,6 +1,5 @@
 package Foo;
 use Foo::Gloom -base;
-use 5.008003;
 
 has 'this';
 
@@ -16,10 +15,10 @@ Ingy döt Net <ingy@cpan.org>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2010. Ingy döt Net.
+Copyright 2010-2014. Ingy döt Net.
 
-This program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
+This program is free software; you can redistribute it and/or modify it under
+the same terms as Perl itself.
 
 See http://www.perl.com/perl/misc/Artistic.html
 
